[pLog-svn] r6893 - in plugins/branches/lifetype-1.2/moblog: class/view templates

jondaley at devel.lifetype.net jondaley at devel.lifetype.net
Wed Jun 3 15:46:52 EDT 2009


Author: jondaley
Date: 2009-06-03 15:46:52 -0400 (Wed, 03 Jun 2009)
New Revision: 6893

Modified:
   plugins/branches/lifetype-1.2/moblog/class/view/adminmoblogpluginsettingsview.class.php
   plugins/branches/lifetype-1.2/moblog/templates/pluginsettings.template
Log:
forgot to put the data for the global article categories in the form

Modified: plugins/branches/lifetype-1.2/moblog/class/view/adminmoblogpluginsettingsview.class.php
===================================================================
--- plugins/branches/lifetype-1.2/moblog/templates/pluginsettings.template	2009-05-29 13:50:11 UTC (rev 6892)
+++ plugins/branches/lifetype-1.2/moblog/templates/pluginsettings.template	2009-06-03 19:46:52 UTC (rev 6893)
@@ -28,8 +28,8 @@
 	<div class="formHelp">{$locale->tr("moblog_global_article_category_help")}</div>
     <select name="globalArticleCategoryId" id="globalArticleCategoryId">
 	  <option value="0" {if 0 == $globalArticleCategoryId} selected="selected" {/if}>{$locale->tr("none")}</option>
-      {foreach from=$globalcategories item=globalcategory}
-        <option value="{$globalcategory->getId()}" {if $globalcategory->getId() == $globalArticleCategoryId} selected="selected" {/if}>{$globalcategory->getName()}</option>
+      {foreach from=$globalArticleCategories item=globalArticleCategory}
+        <option value="{$globalArticleCategory->getId()}" {if $globalArticleCategory->getId() == $globalArticleCategoryId} selected="selected" {/if}>{$globalArticleCategory->getName()}</option>
       {/foreach}
     </select>
     {include file="$admintemplatepath/validate.template" field=globalArticleCategoryId message=$locale->tr("error_no_global_article_category_selected")}	   



More information about the pLog-svn mailing list
--- plugins/branches/lifetype-1.2/moblog/class/view/adminmoblogpluginsettingsview.class.php	2009-05-29 13:50:11 UTC (rev 6892)
+++ plugins/branches/lifetype-1.2/moblog/class/view/adminmoblogpluginsettingsview.class.php	2009-06-03 19:46:52 UTC (rev 6893)
@@ -3,6 +3,7 @@
 	lt_include( PLOG_CLASS_PATH."class/view/admin/adminplugintemplatedview.class.php" );
 	lt_include( PLOG_CLASS_PATH."class/gallery/dao/galleryalbums.class.php" );
 	lt_include( PLOG_CLASS_PATH."class/dao/articlecategories.class.php" );
+	lt_include( PLOG_CLASS_PATH."class/dao/globalarticlecategories.class.php" );
 	
 	/**
 	 * loads and displays the plugin settings
@@ -25,13 +26,19 @@
 			$blogSettings = $this->_blogInfo->getSettings();			
 			$pluginEnabled = $blogSettings->getValue( "plugin_moblog_enabled" );
 			$categoryIds = $blogSettings->getValue( "plugin_moblog_article_category_id" );
+			$globalCategoryId = $blogSettings->getValue( "plugin_moblog_global_article_category_id" );
 			$albumId = $blogSettings->getValue( "plugin_moblog_gallery_resource_album_id" );
 			$resourcePreviewType = $blogSettings->getValue( "plugin_moblog_resource_preview_type" );
 
 			// fetch all the current article categories
 			$categories = new ArticleCategories();
 			$blogCategories = $categories->getBlogCategories( $this->_blogInfo->getId());
-			// fetch all the current gallery albums
+
+                // fetch all the current article categories
+			$globalCategories = new GlobalArticleCategories();
+			$globalCategoriesArray = $globalCategories->getGlobalArticleCategories();
+
+                // fetch all the current gallery albums
 			$albums = new GalleryAlbums();
 			$blogAlbums = $albums->getUserAlbums( $this->_blogInfo->getId());					
 			
@@ -41,6 +48,8 @@
 			$this->setValue( "albumId", $albumId );
 			$this->setValue( "albums", $blogAlbums );
 			$this->setValue( "categories", $blogCategories );
+			$this->setValue( "globalArticleCategoryId", $globalCategoryId );
+			$this->setValue( "globalArticleCategories", $globalCategoriesArray );
 			$this->setValue( "resourcePreviewType", $resourcePreviewType );						
 		
 			parent::render();

Modified: plugins/branches/lifetype-1.2/moblog/templates/pluginsettings.template
===================================================================